"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.reducer = exports.getError = exports.getData = void 0;

const getData = obj => {
  const data = obj && typeof obj.data === 'string' ? JSON.parse(obj.data) : obj;

  if (data && data.data) {
    return data.data;
  } else if (Array.isArray(data)) {
    return data;
  }

  return data;
};

exports.getData = getData;

const getError = obj => {
  if (obj && obj.error && obj.error.Error) return obj.error.Error;
  if (obj && obj.error && obj.error.error) return obj.error.error;
  if (obj && obj.error) return obj.error;
  if (obj && obj.errorMessage) return obj.data;
  return obj;
};

exports.getError = getError;

const reducer = (state, action) => {
  switch (action.type) {
    case 'get':
      return { ...state,
        loading: true,
        complete: false
      };

    case 'loading':
      return { ...state,
        loading: true,
        complete: false
      };

    case 'success':
      return { ...state,
        data: getData(action.payload),
        error: null,
        loading: false,
        complete: true
      };

    case 'error':
      return { ...state,
        data: getData(action.payload.data),
        error: true,
        errorDetails: getError(action.payload),
        loading: false,
        complete: true
      };

    default:
      return state;
  }
};

exports.reducer = reducer;
var _default = reducer;
exports.default = _default;