"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _cookies = _interopRequireDefault(require("./utils/cookies"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * useLocalStorage - Hook to use local storage
 *
 * @param {string} key - The key to save the item in local storage
 * @param {*} initialValue - The initial value
 * @param {boolean} [raw=false] - if the object should be JSON.parsed or not
 * @returns {Array.<{value: object , setFunction: function}>} The value and the setter function
 */
const useCookie = (key, initialValue, options = {}) => {
  const [state, setState] = (0, _react.useState)(() => {
    try {
      const storedValue = _cookies.default.get(key);

      if (typeof storedValue !== 'string') {
        _cookies.default.set(key, JSON.stringify(initialValue), options);

        return initialValue;
      } else {
        return JSON.parse(storedValue || 'null');
      }
    } catch {
      // things happen, it's okay
      return initialValue;
    }
  });
  (0, _react.useEffect)(() => {
    try {
      const serializedState = JSON.stringify(state);

      _cookies.default.set(key, serializedState, options);
    } catch {// things happen, it's okay
    }
  });
  return [state, setState];
};

var _default = useCookie;
exports.default = _default;