"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

/**
 * useEvent Hook to allow binding to DOM events
 *
 * @param {string} eventName - The name of the event
 * @param {function} eventHandler - The handler function
 * @param {*} [target=window] - The entity to bind the event on
 */
const useEventListener = (eventName, handler, target = window) => {
  const refHandler = (0, _react.useRef)();
  (0, _react.useEffect)(() => {
    refHandler.current = handler;
  }, [handler]);
  (0, _react.useEffect)(() => {
    const isSupported = target && target.addEventListener;
    if (!isSupported) return;

    const eventListener = event => refHandler.current(event);

    target.addEventListener(eventName, eventListener);
    return () => {
      target.removeEventListener(eventName, eventListener);
    };
  }, [eventName, target]);
};

var _default = useEventListener;
exports.default = _default;