"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useEvent = exports.default = void 0;

var _react = require("react");

/**
 * useEvent Hook to allow binding to DOM events
 *
 * @param {string} eventName - The name of the event
 * @param {function} eventHandler - The handler function
 * @param {*} [target=window] - The entity to bind the event on
 */
const useEvent = (eventName, eventHandler, target = window) => {
  (0, _react.useEffect)(() => {
    target.addEventListener(eventName, eventHandler);
    return () => {
      target.removeEventListener(eventName, eventHandler);
    };
  }, [eventHandler, eventName, target]);
};

exports.useEvent = useEvent;
var _default = useEvent;
exports.default = _default;