"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useHover = exports.default = void 0;

var _react = require("react");

/**
 * useHover hook that returns if an element is being hovered over
 *
 * @param {*} rel - The reference to the element to be observed
 * @returns {boolean} - The current state of the element if being hovered
 */
const useHover = rel => {
  const [hovered, setHover] = (0, _react.useState)(false);
  (0, _react.useLayoutEffect)(() => {
    const hoverEl = rel.current;

    const onHover = () => setHover(true);

    const offHover = () => setHover(false);

    hoverEl.addEventListener('mouseover', onHover);
    hoverEl.addEventListener('mouseout', offHover);
    return () => {
      hoverEl.removeEventListener('mouseover', onHover);
      hoverEl.removeEventListener('mouseout', offHover);
    };
  }, [rel]);
  return [hovered];
};

exports.useHover = useHover;
var _default = useHover;
exports.default = _default;