"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useKeypress = exports.default = void 0;

var _react = require("react");

/**
 * useKeypress Hook to return true when key is pressed
 *
 * @param {string} key - The text to be used to set the page title
 * @param {HTMLElement} element - The element to listen on for the keypress
 */
const useKeypress = (key, element = window) => {
  const [pressed, setPressed] = (0, _react.useState)(false);

  const onKeyDownEventHandler = e => {
    if (e.key === key) {
      setPressed(true);
    }
  };

  const onKeyUpEventHandler = e => {
    if (e.key === key) {
      setPressed(false);
    }
  };

  (0, _react.useEffect)(() => {
    element.addEventListener('keydown', onKeyDownEventHandler);
    element.addEventListener('keyup', onKeyUpEventHandler);
    return () => {
      element.removeEventListener('keydown', onKeyDownEventHandler);
      element.removeEventListener('keyup', onKeyUpEventHandler);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [key, element]);
  return pressed;
};

exports.useKeypress = useKeypress;
var _default = useKeypress;
exports.default = _default;