"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.useKeypressed = void 0;

var _react = require("react");

/**
 * useKeypressed Hook to return true when key is pressed
 *
 * @param {string} key - The text to be used to set the page title
 * @param {HTMLElement} element - The element to listen on for the keypress
 */
const useKeypressed = (key, element = window) => {
  const [keyPressed, setKeyPressed] = (0, _react.useState)(false);

  const onKeyDownEventHandler = e => {
    if (e.key === key) {
      setKeyPressed(true);
    }
  };

  (0, _react.useEffect)(() => {
    element.addEventListener('keydown', onKeyDownEventHandler);
    return () => {
      element.removeEventListener('keydown', onKeyDownEventHandler);
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [key, element]);
  return keyPressed;
};

exports.useKeypressed = useKeypressed;
var _default = useKeypressed;
exports.default = _default;