"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.useMediaQuery = void 0;

var _react = require("react");

const reducer = (state, action) => {
  switch (action.type) {
    case 'match':
      return {
        matches: true
      };

    case 'nomatch':
      return {
        matches: false
      };

    default:
      return state;
  }
};
/**
 * @typedef {Object} Match~Media
 * @property {boolean} matches - Indicates whether the media query matches.
 */

/**
 * useMediaQuery hook to handle matching a media query
 *
 * @returns {...Match~Media} - The state matching media
 */


const useMediaQuery = mediaQuery => {
  const [state, dispatch] = (0, _react.useReducer)(reducer, {
    matches: false
  });

  const change = query => {
    if (query.matches) {
      dispatch({
        type: 'match'
      });
    } else if (state.matches) {
      dispatch({
        type: 'nomatch'
      });
    }
  };

  const mq = window.matchMedia(mediaQuery);
  mq.addListener(change);
  (0, _react.useEffect)(() => {
    change(mq); // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [mediaQuery]);
  return { ...state
  };
};

exports.useMediaQuery = useMediaQuery;
var _default = useMediaQuery;
exports.default = _default;