"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.usePageVisibility = void 0;

var _react = require("react");

const reducer = (state, action) => {
  switch (action.type) {
    case 'hidden':
      return {
        visible: false,
        hidden: true
      };

    case 'visible':
      return {
        visible: true,
        hidden: false
      };

    default:
      return state;
  }
};
/**
 * @typedef {Object} Page~Visibility
 * @property {boolean} visible - Indicates whether the page is visible.
 * @property {boolean} hidden - Indicates whether the page is hidden
 */

/**
 * usePageVisibility hook to handle page visibility change
 *
 * @returns {...Page~Visibility} - The state of the page
 */


const usePageVisibility = workflow => {
  const [state, dispatch] = (0, _react.useReducer)(reducer, {
    visible: true,
    hidden: false
  });

  const change = e => {
    dispatch({
      type: document.visibilityState
    });
  };

  document.addEventListener('visibilitychange', change);
  return { ...state
  };
};

exports.usePageVisibility = usePageVisibility;
var _default = usePageVisibility;
exports.default = _default;