"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useQuery = void 0;

var _useRequest = require("./use-request");

var _mergeDeep = require("./utils/merge-deep");

const defaultConfig = {
  method: 'POST',
  mode: 'cors',
  cache: 'no-cache',
  credentials: 'same-origin',
  headers: {
    'Content-Type': 'application/json'
  },
  redirect: 'follow',
  referrer: 'no-referrer'
};

const useQuery = (url = '/graphql', query, config = {
  method: 'POST'
}) => {
  const {
    makeRequest,
    ...props
  } = (0, _useRequest.useRequest)(url, {
    data: null,
    error: null,
    loading: false
  });
  const fullConfig = (0, _mergeDeep.mergeDeep)(defaultConfig, config);
  /**
   * postData - Post data to url
   *
   * @param {object} data - the data to post
   */

  const makeQuery = async variables => {
    await makeRequest({ ...fullConfig,
      body: JSON.stringify({
        query,
        variables
      })
    });
  };

  return {
    makeQuery,
    ...props
  };
};

exports.useQuery = useQuery;